==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/db/dbtklmrestore.sh <==
#!/bin/sh
#set -x
#
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Tivoli Key Life Cycle Manager 
# Installer
#
# arg1 -  log  -   log file to be used by this script 
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbname  -  database name
# arg4 -  dbinstance_owner_home - home of the instance owner  
# arg5 -  dbbackupdir  -  directory containing backup file
# arg6 -  dbtimestamp  -  backup time stamp
# arg7 -  dbusername - to execute as db2 user with su
# arg8 -  dbstoptime -  backup time stamp - not used in FP 1 and later versions
#  Note:  The script 
#	        must be run on the same machine where DB2 server is installed.
#		does do not parameter validation
#
#------------------------------------------------------------------------------

LOG=$1
DB_INST=$2
DB_NAME=$3
INST_HOME=$4
DB_BACKUPDIR=$5
DB_TIMESTAMP=$6
DB_USER_NAME=$7
DBSTOPTIME=$8

ARCHLOGDIR=${DB_BACKUPDIR}/${DB_TIMESTAMP}_archd
rm -rf $ARCHLOGDIR
mkdir $ARCHLOGDIR
chmod a+w $ARCHLOGDIR

username=$(whoami)
echo user : $username

#The return code from the script
rc=0

#temporary return code
dbrc=0
argsCount=$#
if [ $argsCount -ne 8 ]
then
echo Number of arguments : $argsCount
echo Usage: dbtklmrestore.sh logfile dbinstance dbname dbinstance_owner_home dbbackupdir dbtimestamp dbusername dbstoptime 
    exit 2
fi


##################################################################
echo "---------------------------------------------------------------------------------------------------" >> $LOG
echo Started executing dbtklmrestore.sh >> "$LOG"
echo "---------------------------------------------------------------------------------------------------" >> $LOG

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ]; then
   CURRENT_DIR=`pwd`
fi


# set instance profile path to source profile of local instance

#source $DB_INST/db2profile
echo . $INST_HOME/sqllib/db2profile >> "$LOG" 
. $INST_HOME/sqllib/db2profile
rc=$?

if [ "$username" != "$DB_USER_NAME" ]; then
	echo db2 stop database manager force >> "$LOG"
	su - $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	rm -rf $INST_HOME/sklmdbarchive/*
	
	echo sleep 2 >> "$LOG"
	su - $DB_USER_NAME -c "sleep 2" >> "$LOG"
	
	echo db2 "start database manager" >> "$LOG"
	su - $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	
	echo "db2 list applications" >> "$LOG"
	su - $DB_USER_NAME -c "db2 list applications" >> "$LOG"
	
	echo "db2 drop db $DB_NAME" >> "$LOG"
	su - $DB_USER_NAME -c "db2 drop db $DB_NAME" >> "$LOG"
	rc=$?
else
	echo db2 stop database manager force >> "$LOG"
	db2 "stop database manager force"  >> $LOG
	rm -rf $INST_HOME/sklmdbarchive/*
	
	echo sleep 2 >> "$LOG"
	sleep 2 >> "$LOG"
	
	echo db2 start database manager >> "$LOG"
	db2 "start database manager"  >> $LOG
	
	echo "db2 list applications" >> "$LOG"
	db2 list applications >> "$LOG"
	
	echo "db2 drop db $DB_NAME" >> "$LOG"
	db2 "drop db $DB_NAME" >> "$LOG"
	rc=$?
fi

echo "grep SQL1013N $LOG" >> "$LOG"
grep "SQL1013N" "$LOG"
dbrc=$?

if [ $dbrc -eq 0 ]; then
  rc=0
fi

if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
  rc=0
fi

if [ $rc -eq 0 ]; then
    echo "db2 restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    if [ "$username" != "$DB_USER_NAME" ]; then
    	su - $DB_USER_NAME -c "db2 restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    	rc=$?
    else
    	db2 "restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    	rc=$?
    fi
    
    if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
        rc=0
    fi
fi

if [ $rc -eq 0 ]; then
    echo "db2 restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR " >> "$LOG"
    if [ "$username" != "$DB_USER_NAME" ]; then
    	su - $DB_USER_NAME -c "db2 restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR" >> "$LOG"
    	rc=$?
    else
    	db2 "restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR" >> "$LOG"
    	rc=$?
    fi
    rc=$?
    if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
        rc=0
    fi
fi


if [ $rc -eq 0 ]; then 
	if [ "$username" != "$DB_USER_NAME" ]; then
	   echo db2 stop database manager force >> "$LOG"
	   su - $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	   
	   echo sleep 2 >> "$LOG"
	   su - $DB_USER_NAME -c "sleep 2" >> "$LOG"
	
	   echo db2 start database manager >> "$LOG"
	   su - $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	   echo "db2 rollforward db $DB_NAME to end of logs AND COMPLETE OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   su - $DB_USER_NAME -c "db2 \"rollforward db $DB_NAME to end of logs AND COMPLETE  OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE\"" >> "$LOG"
	   rc=$?
	else
		echo db2 stop database manager force >> "$LOG"
		db2 "stop database manager force" >> $LOG
		echo sleep 2 >> "$LOG"
		sleep 2 >> "$LOG"
	   echo db2 start database manager >> "$LOG"
	   db2 "start database manager" >> $LOG
	   echo "db2 rollforward db $DB_NAME to end of logs AND COMPLETE OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   db2 "rollforward db $DB_NAME to end of logs AND COMPLETE  OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   rc=$?
	fi	
   
   if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
      rc=0
   fi

   if [ $rc -eq 0 ]; then
   		if [ "$username" != "$DB_USER_NAME" ]; then  
	      echo db2 stop database manager force >> "$LOG"
	      su - $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	      
	      echo sleep 2 >> "$LOG"
		  su - $DB_USER_NAME -c "sleep 2" >> "$LOG"
	
	      echo db2 start database manager >> "$LOG"
	      su - $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	      
	      echo "db2 connect to $DB_NAME" >> "$LOG"
	      su - $DB_USER_NAME -c "db2 connect to $DB_NAME" >> "$LOG"
	
	      echo "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
	      su - $DB_USER_NAME -c "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
		else
	      echo db2 stop database manager force >> "$LOG"
	      db2 "stop database manager force" >> $LOG
	      
	      echo sleep 2 >> "$LOG"
		  sleep 2 >> "$LOG"
	
	      echo db2 start database manager >> "$LOG"
	      db2 "start database manager"  >> $LOG
	      
	      echo "db2 connect to $DB_NAME" >> "$LOG"
	      db2 "connect to $DB_NAME" >> "$LOG"
	
	      echo "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
	      db2 "bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"	
		fi
   fi

fi


rm -rf $ARCHLOGDIR
echo "---------------------------------------------------------------------------------------------------" >> $LOG
if [ $rc -eq 0 ]; then
echo "Return=$rc"
echo "Return=$rc" >> $LOG
else
echo "Return $rc" >> $LOG
fi
echo "---------------------------------------------------------------------------------------------------" >> $LOG
exit $rc

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/db/dbtklmrestore.sh <==
#!/bin/sh
#set -x
#
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Tivoli Key Life Cycle Manager 
# Installer
#
# arg1 -  log  -   log file to be used by this script 
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbname  -  database name
# arg4 -  dbinstance_owner_home - home of the instance owner  
# arg5 -  dbbackupdir  -  directory containing backup file
# arg6 -  dbtimestamp  -  backup time stamp
# arg7 -  dbusername - to execute as db2 user with su
# arg8 -  dbstoptime -  backup time stamp - not used in FP 1 and later versions
#  Note:  The script 
#	        must be run on the same machine where DB2 server is installed.
#		does do not parameter validation
#
#------------------------------------------------------------------------------

LOG=$1
DB_INST=$2
DB_NAME=$3
INST_HOME=$4
DB_BACKUPDIR=$5
DB_TIMESTAMP=$6
DB_USER_NAME=$7
DBSTOPTIME=$8
DB_PRINCIPAL=$9

ARCHLOGDIR=${DB_BACKUPDIR}/${DB_TIMESTAMP}_archd
rm -rf $ARCHLOGDIR
mkdir $ARCHLOGDIR
chmod a+w $ARCHLOGDIR

username=$(whoami)
echo user : $username

#The return code from the script
rc=0

#temporary return code
dbrc=0
argsCount=$#
if [ $argsCount -lt 8 ]
then
echo Number of arguments : $argsCount
echo Usage: dbtklmrestore.sh logfile dbinstance dbname dbinstance_owner_home dbbackupdir dbtimestamp dbusername dbstoptime db2ServicePrincipal
    exit 2
fi


##################################################################
echo "---------------------------------------------------------------------------------------------------" >> $LOG
echo Started executing dbtklmrestore.sh >> "$LOG"
echo "---------------------------------------------------------------------------------------------------" >> $LOG

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ]; then
   CURRENT_DIR=`pwd`
fi


# set instance profile path to source profile of local instance

#source $DB_INST/db2profile
echo . $INST_HOME/sqllib/db2profile >> "$LOG" 
. $INST_HOME/sqllib/db2profile
rc=$?

OS=`uname`

if [ ! -z ${DB_PRINCIPAL} ]; then 
    echo Getting kerberos ticket >> "$LOG"
    kinit_path=$(which kinit)
    if [ "${OS}" == "Linux" ]
    then
        . ~/.bash_profile
    else
        . ~/.profile
    fi
    "$kinit_path" -k -t $KRB5_KTNAME $DB_PRINCIPAL
    if [ "$username" != "$DB_USER_NAME" ]; then
        echo "db2set db2comm=" >> "$LOG"
        su $DB_USER_NAME -c "db2set db2comm=" >> "$LOG"
    else
        echo "db2set db2comm=" >> "$LOG"
        db2set db2comm= >> "$LOG"
    fi        
fi

if [ "$username" != "$DB_USER_NAME" ]; then
	echo db2 stop database manager force >> "$LOG"
	su $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	rm -rf $INST_HOME/sklmdbarchive/*
	
	echo sleep 2 >> "$LOG"
	su $DB_USER_NAME -c "sleep 2" >> "$LOG"
	
	echo db2 "start database manager" >> "$LOG"
	su $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	
	echo "db2 list applications" >> "$LOG"
	su $DB_USER_NAME -c "db2 list applications" >> "$LOG"
	
	echo "db2 drop db $DB_NAME" >> "$LOG"
	su $DB_USER_NAME -c "db2 drop db $DB_NAME" >> "$LOG"
	rc=$?
else
	echo db2 stop database manager force >> "$LOG"
	db2 "stop database manager force"  >> $LOG
	rm -rf $INST_HOME/sklmdbarchive/*
	
	echo sleep 2 >> "$LOG"
	sleep 2 >> "$LOG"
	
	echo db2 start database manager >> "$LOG"
	db2 "start database manager"  >> $LOG
	
	echo "db2 list applications" >> "$LOG"
	db2 list applications >> "$LOG"
	
	echo "db2 drop db $DB_NAME" >> "$LOG"
	db2 "drop db $DB_NAME" >> "$LOG"
	rc=$?
fi

echo "grep SQL1013N $LOG" >> "$LOG"
grep "SQL1013N" "$LOG"
dbrc=$?

if [ $dbrc -eq 0 ]; then
  rc=0
fi

if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
  rc=0
fi

if [ $rc -eq 0 ]; then
    echo "db2 restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    if [ "$username" != "$DB_USER_NAME" ]; then
    	su $DB_USER_NAME -c "db2 restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    	rc=$?
    else
    	db2 "restore DB $DB_NAME FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP  WITHOUT PROMPTING" >> "$LOG"
    	rc=$?
    fi
    
    if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
        rc=0
    fi
fi

if [ $rc -eq 0 ]; then
    echo "db2 restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR " >> "$LOG"
    if [ "$username" != "$DB_USER_NAME" ]; then
    	su $DB_USER_NAME -c "db2 restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR" >> "$LOG"
    	rc=$?
    else
    	db2 "restore DB $DB_NAME logs FROM $DB_BACKUPDIR TAKEN AT $DB_TIMESTAMP LOGTARGET $ARCHLOGDIR" >> "$LOG"
    	rc=$?
    fi
    rc=$?
    if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
        rc=0
    fi
fi


if [ $rc -eq 0 ]; then 
	if [ "$username" != "$DB_USER_NAME" ]; then
	   echo db2 stop database manager force >> "$LOG"
	   su $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	   
	   echo sleep 2 >> "$LOG"
	   su $DB_USER_NAME -c "sleep 2" >> "$LOG"
	
	   echo db2 start database manager >> "$LOG"
	   su $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	   echo "db2 rollforward db $DB_NAME to end of logs AND COMPLETE OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   su $DB_USER_NAME -c "db2 \"rollforward db $DB_NAME to end of logs AND COMPLETE  OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE\"" >> "$LOG"
	   rc=$?
	else
		echo db2 stop database manager force >> "$LOG"
		db2 "stop database manager force" >> $LOG
		echo sleep 2 >> "$LOG"
		sleep 2 >> "$LOG"
	   echo db2 start database manager >> "$LOG"
	   db2 "start database manager" >> $LOG
	   echo "db2 rollforward db $DB_NAME to end of logs AND COMPLETE OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   db2 "rollforward db $DB_NAME to end of logs AND COMPLETE  OVERFLOW log path ($ARCHLOGDIR) NORETRIEVE" >> "$LOG"
	   rc=$?
	fi	
   
   if [ $rc -gt 0 ] && [ $rc -lt 4 ]; then
      rc=0
   fi

   if [ $rc -eq 0 ]; then
   		if [ "$username" != "$DB_USER_NAME" ]; then  
	      echo db2 stop database manager force >> "$LOG"
	      su $DB_USER_NAME -c "db2 stop database manager force"  >> $LOG
	      
	      echo sleep 2 >> "$LOG"
		  su $DB_USER_NAME -c "sleep 2" >> "$LOG"
		  
	      echo "db2set db2comm=tcpip" >> "$LOG"
             su $DB_USER_NAME -c "db2set db2comm=tcpip" >> "$LOG"
	
	      echo db2 start database manager >> "$LOG"
	      su $DB_USER_NAME -c "db2 start database manager"  >> $LOG
	      
	      echo "db2 connect to $DB_NAME" >> "$LOG"
	      su $DB_USER_NAME -c "db2 connect to $DB_NAME" >> "$LOG"
	
	      echo "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
	      su $DB_USER_NAME -c "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
		else
	      echo db2 stop database manager force >> "$LOG"
	      db2 "stop database manager force" >> $LOG
	      
	      echo sleep 2 >> "$LOG"
	      sleep 2 >> "$LOG"
	      
	      echo "db2set db2comm=tcpip" >> "$LOG"
             db2set db2comm=tcpip >> "$LOG"    
	
	      echo db2 start database manager >> "$LOG"
	      db2 "start database manager"  >> $LOG
	      
	      echo "db2 connect to $DB_NAME" >> "$LOG"
	      db2 "connect to $DB_NAME" >> "$LOG"
	
	      echo "db2 bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"
	      db2 "bind '$INST_HOME/sqllib/bnd/db2schema.bnd' blocking all grant public sqlerror continue" >> "$LOG"	
		fi
   fi

fi


rm -rf $ARCHLOGDIR
echo "---------------------------------------------------------------------------------------------------" >> $LOG
if [ $rc -eq 0 ]; then
echo "Return=$rc"
echo "Return=$rc" >> $LOG
else
echo "Return $rc" >> $LOG
fi
echo "---------------------------------------------------------------------------------------------------" >> $LOG
exit $rc
